.TH XWTEXTEDIT 3X
.SH NAME
XwtexteditWidgetClass \- An X Widget for viewing and editing
text.
.SH SYNOPSIS
#include <X11/StringDefs.h>
.br
#include <X11/Intrinsic.h>
.br
#include <Xw/Xw.h>
.br
#include <Xw/TextEdit.h>
.SH CLASSES
TextEdit is a subclass of CoreClass and XwPrimitiveClass.
.PP
The widget class record to use when creating a text edit
widget is XwtexteditWidgetClass.
.PP
The class name for TextEdit is TextEdit.
.SH OVERVIEW
TextEdit provides a single and multi-line text editor which
has both a customizable user interface and a programmatic
interface.  It can be used for single-line string entry,
forms entry with verification procedures, multiple-page
document viewing, and full-window editing.  It provides an
application with a consistent editing paradigm for entry of
textual data.
.PP
The display of the textual data on the screen can be
adjusted to the application writer's need based on four
class resources, XtNwrap, XtNwrapBreak, XtNscroll, and
XtNgrow.  XtNwrapP controls automatic line breaking for
lines that extend off the end of the screen.  XtNscroll
controls horizontal and vertical shifting of the text when
the insertion cursor moves off the screen.  XtNgrow controls
attempts by the widget to resize its window to make more
room for text that extends beyond the current screen size.
These resources are explained in detail below.
.PP
TextEdit provides separate callback lists to verify
insertion cursor movement, modification of the text, and
leaving the TextEdit widget.  Each of these callbacks
provides the verification function with the widget instance,
the event that caused the callback, and a data structure
specific to the verification type.  From this information
the function can verify if the application considers this to
be a legitimate state change and signal the widget whether
to continue with the action.  The verification function can
also manipulate the widget through the class methods defined
by the TextEdit class.  The verification callback lists are
explained in detail below.
.PP
The user interface can be tailored by providing a new set of
translations.  The default translations provide commands for
movement, deletion, killing and selection with key bindings
similar to an EMACS style editor.
.PP
TextEdit allows the user to select regions of text.  By
using TextEdit's selection mechanism, application writers
can easily fit instances of TextEdit into X11's current
selection mechanism.
.PP
The TextEdit class controls the data structures for drawing
the text on the screen and defines the functions that
manipulate that data.  The storage of the text is provided
by a separate component called the Source.  The Source
provides the storage of the textual data and a set of
functions for querying and changing that data.  The
application writer can provide a new source for the TextEdit
widget.  The details are provided below.
.SH "NEW RESOURCES"
TextEdit defines the following new resources:
.IP "" 20
TextEdit Resource Set
.RE
.nf
Name			Class			Type		Default
_______________________________________________________________________
XtNsourceType		XtCSourceType		String		"stringsrc"
XtNsource		XtCTextSource		Pointer		StringSrc
XtNdisplayPosition	XtCTextPosition	XtTextPosition	0
XtNinsertPosition	XtCTextPosition	XtTextPosition	0
XtNselectionLeft	XtCSelectionLeft	XtTextPosition	0
XtNselectionRight	XtCSelectionRight	XtTextPosition	0
XtNwrap		XtCWrap		XwWrap	XwWrapOff
XtNwrapBreak		XtCWrapBreak		XwWrapBreak	XwWrapWhiteSpace
XtNscroll		XtCScroll		XwScroll	XwAutoScrollOff
XtNgrow		XtCGrow		XwGrow	XwGrowOff
XtNleftMargin		XtCMargin		Dimension	3 See Note Below
XtNrightMargin		XtCMargin		Dimension	3 See Note Below
XtNtopMargin		XtCMargin		Dimension	3 See Note Below
XtNbottomMargin	XtCMargin		Dimension	3 See Note Below
XtNmotionVerification	XtCCallback		XtRCallback	NULL
XtNmodifyVerification	XtCCallback		XtRCallback	NULL
XtNleaveVerification	XtCCallback		XtRCallback	NULL
XtNexecute		XtCallback		XtRCallback	NULL
.fi
.br
.TP 5
XtNtranslations
.br
The set of default translations are described below.
.TP 5
XtNdisplayPosition
.br
The position in the text source that will be displayed
.IP "" 5
at the top of the screen.  The default is 0, or the
start of the text source.
.TP 5
XtNinsertPosition
.br
The position in the text source of the insert cursor.
The default is 0.
.TP 5
XtNselectionLeft
.br
The starting position of the initial selection.  The
default is 0.
.TP 5
XtNselectionRight
.br
The ending position of the initial selection.  The
default is 0.
.TP 5
XtNsourceType
.br
This defines the type of the text source. It is one of
"stringsrc," "disksrc" or "progdefinedsource."
.TP 5
XtNsource
.br
This specifies a new Source.  The default is StringSrc.
.TP 5
XtNwrap
.br
This resource specifies how the widget displays lines
longer than the screen width.  When set to XwWrapOff,
the lines may extend off screen to the right.  When set
to XwSoftWrap, the lines will be wrapped at the right
margin with the actual position determined by the
resource XtNwrapBreak.
.TP 5
XtNwrapBreak
.br
This resource specifies how the wrap position is
determined.  When set to XwWrapAny, the wrap will
happen at the character position closest to the right
margin.  When set to XwWrapWhiteSpace, the wrap will
happen at the last whitespace before the right margin.
If the line does not have whitespace, it will be
wrapped as XwWrapAny.
.TP 5
XtNscroll
.br
This resource controls the horizontal and vertical
scrolling of lines longer than the screen width.  When
set to XwAutoScrollOff the widget will not scroll.
.br
When set to XwAutoScrollVertical, the widget will
scroll lines vertically.  When set to
XwAutoScrollHorizontal, the widget will scroll a
single-line display horizontally.  Horizontal scrolling
is not currently supported for multi-line displays.
Both horizontal and vertical scrolling can be set with
XwAutoScrollBoth (again, subject to the single-line
horizontal restriction).  The default is
.IP "" 5
XwAutoScrollOff.  XtNscroll has lower priority than
XtNwrap, meaning if wrapping is enabled, the widget
will attempt to wrap to the next line before it will
attempt to scroll horizontally.
.TP 5
XtNgrow
.br
This resource controls if the widget will try to resize
its window when it needs more height or width to
display the text.  When set to XwGrowOff it will not
resize itself.  When set to XwGrowHorizontal it will
attempt to change its width when lines are too long for
the current screen width.  When set to XwGrowVertical
it will attempt to resize its height when the number of
text lines is greater than can be displayed with the
current screen height.  When set to XwGrowBoth, the
widget will attempt resizes in both dimensions.  Growth
attempts have higher priority than either wrapping or
scrolling.  If enabled, the widget will always try to
grow to display text before trying to wrap or scroll.
The default is XwGrowOff.  The success of a resize
request is determined by the widget's parent.
.TP 5
XtNleftMargin
.br
The number of pixels used for the left margin.
.IP "" 5
NOTE: if TextEdit is embedded in a manager with
keyboard traversal enabled, it will silently enforce
the constraint that all margins must be at least 3
pixels wider than the highlight border width.
.TP 5
XtNrightMargin
.br
The number of pixels used for the right margin.
.TP 5
XtNtopMargin
.br
The number of pixels used for the top margin.
.TP 5
XtNbottomMargin
.br
The number of pixels used for the bottom margin.
.TP 5
XtNmotionVerification
.br
This verification callback list is called before the
insertion cursor is moved to a new position.  The
default is NULL.  See the verification section below.
.TP 5
XtNmodifyVerification
.br
This verification callback list is called before text
is deleted from or inserted to the text source.  The
default is NULL.  See the verification section below.
.TP 5
XtNleaveVerification
.br
This verification callback list is called before the
.IP "" 5
widget loses input focus.  The default is NULL.  See
the verification section below.
.TP 5
XtNexecute
.br
This callback list is similar to a selection function
on a button.  When the user invokes an event that calls
the "execute" function (see the translation table
below), this callback list will be executed. In the
default translation table, this is bound to the "enter"
key.
.TP 0
.ti -5
SUBCOMPONENT RESOURCES
.br
StringSrc defines the following new resources.  In a
resource file they can be specified by the name stringsrc
under the name of the TextEdit widget, or through the class
StringSrc.
.IP "" 16
StringSrc Resource Set
.RE
.nf
Name			Class		Type		Default
______________________________________________________
XtNstring		XtCString	char *		NULL
XtNmaximumSize	XtCLength	int		NULL
XtNeditType		XtCEditType	XtEditType	XwtextEdit
.fi
.TP 5
XtNstring
.br
The initial string to be viewed and/or edited.  The
default is the empty string.  An XtGetValues call on
this resource will return a copy of the internal
buffer. The application program is responsible for
freeing the space allocated by the copy. An XtSetValues
call will copy the given string into the internal
buffer.
.TP 5
XtNmaximumSize
.br
The maximum number of characters that can be entered
into the internal buffer.  If this value is not set
then the internal buffer will increase its size as
needed limited only by the space limitations of the
process.
.TP 5
XtNeditType
.br
This resource controls the edit state of the source.
.br
It can be XttextRead, a read only source, XttextAppend,
a source than can only be appended to, and XttextEdit,
a fully editable source.
.IP "" 5
DiskSrc defines the following new resources.  In a
resource file they can be specified by the name disksrc
.IP "" 5
under the name of the TextEdit widget, or through the
class DiskSrc.
.IP "" 17
DiskSrc Resource Set
.RE
.nf
Name		Class		Type		Default
___________________________________________________
XtNfile		XtCFile		char *		NULL
XtNeditType	XtCEditType	XtEditType	XwtextEdit
.fi
.TP 5
XtNfile
.br
The absolute pathname of a disk file to be viewed
and/or edited.  If no file is given, a temporary file
will be created.
.TP 5
XtNeditType
.br
This resource controls the edit state of the source.
.br
It can be XttextRead, a read only source, and
XttextAppend, a source than can only be appended to.
.IP "" 5
Display defines the following new resources.  In a
resource file they can be specified by the name display
under the name of the TextEdit widget, or through the
class Display.
.IP "" 17
Display resource Set
.RE
.nf
Name		Class		Type		Default
_______________________________________________________
XtNfont	XtCFont	XFontStruct *	Fixed
XtNforeground	XtCForeground	XtRPixel	Black
.fi
.TP 5
XtNfont
.br
The font used to display the text.  The default is
fixed.  There are currently several display bugs
associated with proportional fonts.
.TP 5
XtNforeground
.br
The color for drawing the text.  The default is black.
.SH "INHERITED RESOURCES"
The following resources are inherited from the indicated
superclasses:
.IP "" 17
Core Resource Set \-\- CORE(3X)
.RE
.nf
Name				Class				Type		Default
_______________________________________________________________________________________
XtNancestorSensitive		XtCSenstitive			Boolean		TRUE
XtNx				XtCPosition			int		0
XtNy				XtCPosition			int		0
XtNwidth			XtCWidth			int		0
XtNheight			XtCHeight			int		0
XtNdepth			XtCDepth			int		0
XtNbackground			XtCBackground			Pixel		White
XtNbackgroundPixmap		XtCPixmap			Pixmap		Unspecified
XtNborderWidth		XtCBorderWidth		int		1
XtNborderColor			XtCBorderColor			Pixel		Black
XtNborderPixmap		XtCPixmap			Pixmap		Unspecified
XtNsensitive			XtCSensitive			Boolean		TRUE
XtNmappedWhenManaged	XtCMappedWhenManaged	Boolean		TRUE
XtNdestroyCallback		XtCCallback			Pointer		NULL
XtNtranslations			XtCTranslations		XtTranslations	NULL
.fi
.br
.IP "" 10
Primitive Resource Set \-\- XWPRIMITIVE(3X)
.RE
.nf
Name			Class			Type		Default
________________________________________________________________________
XtNforeground		XtCForeground		Pixel		Black
XtNbackgroundTile	XtCBackgroundTile	int		background
XtNtraversalType	XtCTraversalType	int		highlight_off
XtNhighlightStyle	XtCHighlightStyle	int		pattern_border
XtNhighlightColor	XtCForeground		Pixel		Black
XtNhighlightTile	XtCHighlightTile	int		50_foreground
XtNhighlightThickness	XtCHighlightThickness	int		0
XtNrecomputeSize	XtCRecomputeSize	Boolean		TRUE
XtNselect		XtCCallback		Pointer		NULL
XtNrelease		XtCCallback		Pointer		NULL
.fi
.br
.SH "KEYBOARD TRAVERSAL"
If the XtNtraversalType resource is set to
highlight_traversal (XwHIGHLIGHT_TRAVERSAL in an argument
list) at either create time or during a call to XtSetValues,
the XwPrimitive superclass will automatically augment the
primitive widget's translations to support keyboard
traversal.  Refer to the XwPrimitive man page for a complete
description of these translations.  Refer to the
TRANSLATIONS section in this man page for a description of
the translations local to the scrolled window widget.
.SH TRANSLATIONS
Since TextEdit has full editing functionality, it supports
an elaborate set of translations.  The following table lists
TextEdit's default translations which are a subset of key
bindings from an EMACS editor.  (An EMACS editor refers to a
set of editors based on the original design of R.M. Stallman
at MIT for an extensible, customizable self-documenting
display editor.) TextEdit supports the concept of delete and
kill.  Both delete and kill remove a unit of text from the
text source, but text that has been removed with a kill can
be restored by an unkill action.  Kills are stored in the X
Cutbuffer 1, so that a kill in one instance of a TextEdit
widget can be inserted into another instance of a TextEdit
widget.  TextEdit does not support a history of kills in a
kill ring, nor the appending of kills made in sequence.
TextEdit highlights the current selection by reversing the
foreground and background color.  Text that has been copied
from TextEdit into the current selection storage can be
inserted into the buffer with a stuff action.
.PP
Each of these functions can be rebound to a different key in
the default translation file set in .Xdefaults.  The string
to identify the function is identical to the function name
used below.  An example line in that file to bind Control-I
to move the insertion point forward one word is:
.IP "" 21
Ctrl<Key>I:    forward-word
.PP
See the Xt Intrinsics documention for more information on
the Xdefaults file and translations.
.PP
TextEdit works with keyboard traversal and defines the
required actions.
.ti -5
.PP
DEFAULT KEY BINDINGS FOR TEXTEDIT
.br
.IP "" 23
Movement
.RE
.nf
__________________________________
Ctrl F		forward-character
Right Arrow	forward-character
Ctrl B		backward-character
Left Arrow	backward-character
Meta F		forward-word
Meta B		backward-word
Meta ]		forward-paragraph
Ctrl [		backward-paragraph
Ctrl A		beginning-of-line
Ctrl E		end-of-line
Ctrl N		next-line
Down Arrow	next-line
Ctrl P		previous-line
Up Arrow	previous-line
Ctrl V		next-page
Next		next-page
Meta V		previous-page
Prev		previous-page
Meta <		beginning-of-file
Home		beginning-of-file
Meta >		end-of-file
Shift Home	end-of-file
Ctrl Z		scroll-one-line-up
Meta Z		scroll-one-line-down
.fi
.IP "" 16
Delete Kill and Stuff
.RE
.nf
________________________________________
Ctrl D		delete-next-character
Ctrl H		delete-previous-character
Meta D:		delete-next-word
Meta H		delete-previous-word
Shift Meta D	kill-word
Shift Meta H	backward-kill-word
Ctrl W		kill-selection
Ctrl K		kill-to-end-of-line
Meta K		kill-to-end-of-paragraph
Ctrl Y		unkill
Meta Y		stuff
.fi
.IP "" 20
Miscellaneous
.RE
.nf
______________________________________
Ctrl J			newline-and-indent
Ctrl O			newline-and-backup
Ctrl M			newline
<Btn1Down>		select-start
Button1<PtrMoved>	extend-adjust
<Btn1Up>		extend-end
<Btn2Down>		stuff
<Btn3Down>		extend-start
Button3<PtrMoved>	extend-adjust
<Btn3Up>		extend-end
Ctrl L			redraw-display
<Key>		insert-char
.fi
.SH "KEYBOARD TRAVERSAL"
The following table summarizes the keystrokes which (when
keyboard traversal is active) will move the focus. The keys
used elsewhere in the X Widgets library for keyboard
traversal are used for other purposes in the text edit
widget.  Therefore, it was necessary to define other
keystokes to serve these functions.  To minimize the
incompatibility the decision was made to use the same keys
with the addition of the Ctl modifier to implement keyboard
traversal in this widget.
.IP "" 18
Keyboard Traversal
.RE
.nf
______________________________
Ctrl Up		traverse-up
Ctrl Down	traverse-down
Ctrl Left	traverse-left
Ctrl Right	traverse-right
Ctrl Next	traverse-next
Ctrl Prev	traverse-prev
Ctrl Home	traverse-home
Enter		traverse-next-top
.fi
.TP 5
traverse-up:
.br
Inform the parent of this widget that it should
transfer keyboard focus to the first widget above this
one.
.TP 5
traverse-down:
.br
Inform the parent of this widget that it should
transfer keyboard focus to the first widget below this
one.
.TP 5
traverse-left:
.br
Inform the parent of this widget that it should
transfer keyboard focus to the first widget to the left
of this one.
.TP 5
traverse-right:
.br
Inform the parent of this widget that it should
transfer keyboard focus to the first widget to the
right of this one.
.TP 5
traverse-next:
.br
Inform the parent of this widget that it should
transfer keyboard focus to the next child in the
parent's list of children.
.TP 5
traverse-prev:
.br
Inform the parent of this widget that it should
transfer keyboard focus to the previous child in the
parent's list of children.
.TP 5
traverse-home:
.br
Inform the parent of this widget that it should
transfer keyboard focus to the child which is closest
to the uppper left hand corner of the parent.  If that
child already has the keyboard focus, then ask the
grandparent of this widget to give the keyboard focus
to whichever of its children which is closest to the
upper left hand corner.
.TP 5
traverse-next-top:
.br
Find the topmost parent in this widget hierarch which
is a subclass of XwManager and tell it to issues any
XtNnextTop callbacks that have been registered with it.
The purpose of this callback is to allow applications
to move the keyboard focus between top level widget
hierarchies of the same application.
.TP 0
.ti -5
DISPLAYING TEXT, WORD WRAP AND ACTIONS
.br
Text is considered to be hierarchically composed of white
space, words, lines and paragraphs.  These component
concepts are currently hard-coded, but we intend that future
versions will support a more general version of the text
composition hierarchy.  White space is defined as any non-\c
empty sequence of the ASCII characters space, tab, linefeed
or carriage return (decimal values of 32, 9, 10, 13,
respectively); a word is any non-empty sequence of
characters bounded on both sides by whitespace.  A source
line is any (possibly empty) sequence of characters bounded
by newline characters; a display line is any (possibly
empty) sequence of characters appearing on a single screen
display line.  A source paragraph is any sequence of
.PP
characters bounded by sets of two or more adjacent newline
characters.  a display paragraph is any (possibly empty)
sequence of characters bounded by newline characters (NOTE:
this is identical to the definition of a source line).  In
all cases, the beginning or end of the edit text is an
acceptable bounding element in the previous definitions.
.PP
When making display decisions, TextEdit first determines
whether all the text will fit in the current display.  If it
does not, and growing is enabled, the widget will make
resize request of its parent.  If the request is denied or
only partially satisfied, no future growth requests will be
made unless there is an intervening resize operation
externally imposed.  If any source line is still too long to
fit in the display after growing is attempted, wrapping is
checked.  If wrap is off (XwWrapOff), one display line is
drawn for each source line.  If a source line is too long
for the display, it is truncated at the right margin after
the last full character which fits.  If wrapping is enabled
(XwSoftWrap), a new display line will be started with the
first word which doesn't fit on the current line.  If the
wrap break option is XwWrapAny, as many characters from that
word as will fit before the right margin are written to the
current display line, then the next character starts at the
left margin of the next display line.  If the wrap break
option is XwWrapWhiteSpace, the line break is instead made
after the first whitespace character which follows the last
full word which does fit on the current display line.  If,
however, under white space break, the first full word which
does not fit is also the first word on the line, the wrap
break is made as if XwWrapAny were selected.
.TP 0
.ti -5
VERIFICATION CALLBACKS
.br
Three types of verification callbacks are supported by
TextEdit There is one for motion operations, to verify a new
insert position; there is one for modifying operations, to
verify insertion, deletion or replacement of text; there is
one for widget exit, to verify state consistency on loss of
focus by the widget.  Each verification callback procedure
is of type XtCallbackProc, which defines the three arguments
it will be invoked with.  These are the id of the widget
making the callback, the client data which was specified by
the client application when the callback was registered (see
XtAddCallback), and a pointer (type XwTextVerifyPtr) to the
verification call_data structure.  The C data types used
here are:
.PP
typedef enum {motionVerify, modVerify, leaveVerify} opType ;
.PP
.IP "" 6
.RE
.nf
typedef struct {
		XEvent         *xevent ;
		opType          operation ;
		boolean         doit ;
		XtTextPosition  currInsert, newInsert ;
		XtTextPosition  startPos, endPos ;
		XtTextBlock    *text ;
	} XwTextVerifyCD, *XwTextVerifyPtr ;
.PP
Before the chain of verification callbacks is activated for
any given operation, a structure of type XtTextVerifyCD is
initialized.  The initial values are:
.TP 17
xevent:       for a leave operation, the current
.br
event pointer
.TP 17
operation:    element of opType signifying the
.br
type of verification operation
.IP "" 3
doit:         TRUE
.TP 17
currInsert:   current position of the insert
.br
point
.TP 17
newInsert:    for a motion operation, the
.br
position the user is attempting to
.br
move the insert point to,
.br
otherwise, the same value as
.br
currInsert
.TP 17
startPos:     for a modify operation, the
.br
beginning position in the current
.br
source of the text about to be
.br
deleted or replaced, or where new
.br
text will be inserted.  If not a
.br
modify operation, the same value as
currInsert.
.TP 17
endPos:       for a modify operation, the ending
.br
position in the current source of
.br
the text about to be deleted or
.br
replaced.  If no text is being
.br
removed, it will have the same
.br
value as startPos.  If not a modify
operation, the same value as
.br
currInsert.
.TP 17
text:         for a modify operation with new
.br
text to be inserted, a pointer to a
structure of type XtTextBlock,
.br
which references the text to be
.br
inserted.  Otherwise, NULL.
.IP "" 1
.ti -6
It is possible for the client to register more than one callback
.br
.ti -6
procedure for any of these callback types.  The order in which
.br
.ti -6
the callbacks will be invoked is described in the toolkit
.br
.ti -6
documentation.  Since there can be more than one callback, each
.br
.ti -6
verification procedure should first check the doit field.  If it
.br
.ti -6
is false, someone else has already rejected the operation, so
.br
.ti -6
there is no need for further evaluation.  On return from invoking
.br
.ti -6
the chain of callbacks, the TextEdit widget will look at the doit
.br
.ti -6
member of the XtTextVerifyCD structure.  If it is still true,
.br
.ti -6
TextEdit will proceed with operation, otherwise it will not.  Any
.br
.ti -5
.PP
user feedback for the rejected operation is the responsibility of
.br
.ti -5
the verification procedure.  Verification callbacks are permitted
.br
.ti -5
to modify some of the data in the XtTextVerifyCD structure.  The
.br
.ti -5
TextEdit widget will only look at certain fields on return,
.br
.ti -5
though, according to the operation type.  For a motion operation,
.br
.ti -5
only the newInsert position will be looked at.  For a modify
.br
.ti -5
operation, only startPos, endPos and text will be examined for
.br
.ti -5
changes.  For leave operation, no fields will be examined.  There
.br
.ti -5
is no mechanism for preventing a verification callback from
.br
.ti -5
making other changes to the editing state through the documented
.br
.ti -5
interface, but such behind-the-back actions are discouraged.
.br
.TP 0
.ti -5
APPLICATION WRITER'S INTERFFACE
.br
The state of TextEdit can be changed in through the normal
functional interface to widgets (XtSetValues and
XtGetValues) or by exported external functions.
.PP
TextEdit's resources can be queried and set through
XtSetValues and XtGetValues.  The widget will maintain its
display consistent with the new values.  In particular this
is the method for changing the display options.
.PP
The internal buffer should be manipulated through the
external functions that follow.
.PP
This set of external functions is designed to allow the
widget programmer to access the internal buffer that
TextEdit manages.  For example, if the widget is being used
to enter a string, the program can get a copy of the string
(i.e. the internal buffer) with the function
XwTextCopyBuffer or XwTextReadSubString.  All of the
following functions that change the contents of the buffer,
its selection, or insertion position, will update the
display after they are called.  If the programmer needs to
make a sequence of these calls, the widget's screen updating
function should be turned off with a call to
XwTextUpdate(Off) to prevent screen flash.  After the
sequence of calls the programmer must remember to call
XwTextUpdate(On) to update the window and resume normal
updating.  Note that it is not necessary to turn off the
update function for functions that only get values from the
widget.  Neither is it necessary to use these calls if the
programmer only makes one call that changes the widget.
.TP 5
Buffer Functions
.br
void XwTextClearBuffer(w)
.br
.ti +15
XwTextEditWidget w;
.br
Clear the internal buffer.  After this call all
characters in the buffer have been removed.
.TP 21
unsigned char *XwTextCopyBuffer(w)
.br
XwTextEditWidget w;
This function uses XtMalloc to create space to make a
copy of the internal buffer and returns the pointer to
that copy.  The application writer is responsible for
freeing the space.
.TP 5
Read a Substring
.br
int XwTextReadSubString( w, startpos, endpos, target, targetsize, targetused )
.ti +2
XwTextEditWidget  w;
.br
.ti +2
XwTextPosition    startpos, endpos;
.br
.ti +2
unsigned char     *target;
.br
.ti +2
int               targetsize,
.br
.ti +20
*targetused;
.br
This function will move characters from the buffer into
the caller's space.  The caller must provide the space
to copy into and its size in bytes.  The routine will
return the number of positions moved.  The value of
targetused returns the number of bytes used in the
target string by the move.
.TP 5
Selection
.br
unsigned char *XwTextCopySelection(w)
.br
.ti +3
XwTextEditWidget w;
.br
This function uses XtMalloc to create space to make a
copy of the current selection and returns the pointer
to that copy.  The application writer is responsible
for freeing the space.
.TP 9
void XwTextUnsetSelection(w)
.br
XwTextEditWidget w;
This function will clear the current selection.
.IP "" 5
void XwTextSetSelection(w, left, right)
.ti +2
XwTextEditWidget  w;
.br
.ti +2
XwTextPosition    left, right;
.br
This function sets the current selection to be between
the character positions left to right.
.IP "" 5
void XwTextGetSelectionPos(w, left, right)
.ti +5
XwTextEditWidget w;
.br
.ti +5
XwTextPosition *left, *right;
.br
This function returns the character positions of the
current selection.
.TP 5
Insertion and Deletion
.br
void XwTextInsert(w, string)
.br
.ti +5
XwTextEditWidget w;
.br
.ti +5
unsigned char *string;
.br
.IP "" 5
This function inserts the string at the current
insertion position and advances the insertion position
to the end of the string.
.IP "" 5
XwEditResult XwTextReplace(w, startPos, endPos, text)
.ti +2
XwTextEditWidget         w;
.br
.ti +2
XwTextPosition startPos,
.br
.ti +17
endPos;
.br
.ti +2
unsigned char  *text;
.br
Remove text in the source from startPos to endPos and
insert the string text starting at startPos.  If
startPos and endPos are the same the action is an
insertion.  If text is the empty string, the action is
a deletion.
.TP 5
Drawing and Updating
.br
XwTextRedraw(w);
.br
.ti +2
XwTextEditWidget w;
.br
Refresh the widget screen.
.TP 9
void XwTextUpdate( w, status )
.br
XwTextEditWidget w;
.br
Boolean status;
This function turns the widget's screen updating
function on and off. Wrapping these calls around a
sequence of calls that change the content of the
internal buffer will prevent screen flash.
.TP 5
End of Buffer
.br
XwTextPosition XwTextGetLastPos (w, lastPos)
.ti +4
XwTextEditWidget w;
.br
.ti +4
XwTextPosition lastPos;
.br
This function returns the last character position in
the buffer.
.TP 5
Insertion Position
.br
void XwTextSetInsertPos(w, position)
.br
.ti +5
XwTextEditWidget w;
.br
.ti +5
XwTextPosition position;
.br
.TP 10
XwTextPosition XwTextGetInsertPos(w)
.br
XwTextEditWidget w;
These functions set and return the insertion position.
.TP 5
Setting the Source
.br
void XwTextSetSource(w, source, startpos)
.ti +5
XwTextEditWidget w;
.br
.ti +5
XwTextSourcePtr source;
.br
.ti +5
XwTextPosition startpos;
.br
.SH "SOURCE DEFINITION"
The source provides textual data space and functions for
manipulating that data.  The functions are defined below.
.br
An application can define its own source by reimplementing
these functions.
.TP 5
Read
.br
XwTextPosition SourceRead(src, pos, text, maxread)
.ti +6
XwTextsource    *src;
.br
.ti +6
XwTextPosition   pos;
.br
.ti +6
XwTextblock     *text;
.br
.ti +6
XwTextPosition   maxread;
.br
This function returns a read-only text block in the src
with maxread number of characters starting from pos.
The return value is the next character position
following the block.
.TP 5
Replace
.br
XwEditResult SourceReplace(src, startpos, endpos, textblk, delta)
.ti +6
XwTextsource    *src;
.br
.ti +6
XwTextPosition  startpos,
.br
.ti +22
endpos;
.br
.ti +6
XwTextBlock     *textblk;
.br
.ti +6
XwTextPosition             *delta;
.br
This function removes existing text in src between
startpos and endpos and inserts new text from textblk
at startpos.  delta is change in the size of the text
source.  It returns XweditDone for a successful
operation, XweditPosError for positional errors when
source is in XttextAppend mode, and XweditError when
the operation could not be performed.
.TP 5
SetLastPosition
.br
XwTextPosition SourceSetLastPos(src, lastpos)
.ti +2
XwTextSource   *src;
.br
.ti +2
XwTextPosition lastpos;
.br
This functions sets the last position in the source.
.TP 5
Scan
.br
XwTextPosition SourceScan(src, pos, scantype, dir, count, include)
.ti +2
XwTextsource    *src;
.br
.ti +2
XwTextPosition  pos;
.br
.ti +2
XwScanType        scantype;
.br
.ti +2
XwScanDirection   dir;
.br
.ti +2
int             count;
.br
.ti +2
Boolean         include;
.br
SourceScan searches in dir direction (XwsdLeft
XwsdRight) for XwScantype (XwstPositions,
XwstWhiteSpace, XwstEOL, XwstParagraph, XwstLast).
count is the number of the given type it will scan over
.IP "" 5
and include indicates whether to count the item
currently pointing at.  It returns the starting
position of the item scanned for.
.TP 5
EditType
.br
XtEdittype SourceEditType(src)
.br
.ti +2
XwTextsource  *src;
.br
Returns the edit type of source.
.SH "CURRENT LIMITATIONS"
The current default source is not optimized for large
amounts of data.  X11's current selection is not yet
supported.
.SH ORIGIN
Digital Equipment Corporation.  Massachusetts Institute of
Technology.  Hewlett-Packard Company.
.SH "SEE ALSO"
CORE(3X), XWPRIMITIVE(3X),
.br
Programming With The HP X Widgets,
.br
Programming With Xt Intrinsics,
.br
Programming With Xlib.
