.TH XWCASCADE 3X
.SH NAME
XwcascadeWidgetClass \- the X Widgets popup and pulldown
menupane widget.
.SH SYNOPSIS
#include <X11/Intrinsic.h>
.br
#include <X11/StringDefs.h>
.br
#include <Xw/Xw.h>
.br
#include <Xw/Cascade.h>
.SH CLASSES
The Cascade menupane widget is built from the Core,
Composite, Constraint, XwManager and XwMenuPane classes.
Note that the Constraint fields are not used in this widget
and are not listed in the resource tables below.  Also,
since the Composite class contains no resources that can be
set by the user, there is no table for Composite class
resources.
.PP
The widget class to use when creating a cascading menupane
is XwcascadeWidgetClass.  The class name is Cascade.
.SH DESCRIPTION
The Cascade menupane widget is a composite widget which may
be used by an application when creating a set of menus.
.PP
The Cascade menupane widget always displays its managed
children in a single column, and always attempts to size
itself to the smallest possible size, as described by the
children it contains; as the children grow or shrink in
size, the menupane will attempt to adapt its size
accordingly.
.PP
The Cascade menupane widget allows a title to be displayed
at the top of the menupane, the bottom of the menupane, or
at both places.  Additionally, the title may be either a
text string or an image.  The title is always centered
horizontally within the menupane.
.PP
Refer to the manual page for XwManager(3X) for a description
of how to specify the order in which menubuttons are
inserted into a menupane.
.SH "NEW RESOURCES"
The MenuPane defines a set of resource types used by the
programmer to specify the data for the menupane.  The
programmer can also set the values for the Core, Composite
Manager and MenuPane widget classes to set attributes for
this widget.  To specify any of these resources within the
\&.Xdefaults file, simply drop the XtN prefix from the
.PP
resource name.  The following table contains the set of
resources defined by Cascade.
.IP "" 17
Cascade Resource Set
Name               Class              Type   Default
____________________________________________________
XtNtitlePosition   XtCTitlePosition   int    top
.TP 5
XtNtitlePosition
.br
This resource is used to control where the title is
displayed within the cascading menupane.  To
programmatically set this resource, use either the
XwTOP, XwBOTTOM or XwBOTH define.  To set this resource
using the .Xdefaults file, use one of the strings top,
bottom or both.
.SH "INHERITED RESOURCES"
The following resources are inherited from the named
superclasses:
.IP "" 17
Core Resource Set \-\- CORE(3X)
.ti -22
Name                   Class                  Type             Default
.br
.ti -22
__________________________________________________________________________
.br
.ti -22
XtNancestorSensitive   XtCSenstitive          Boolean          TRUE
.br
.ti -22
XtNx                   XtCPosition            int              0
.br
.ti -22
XtNy                   XtCPosition            int              0
.br
.ti -22
XtNwidth               XtCWidth               int              0
.br
.ti -22
XtNheight              XtCHeight              int              0
.br
.ti -22
XtNdepth               XtCDepth               int              0
.br
.ti -22
XtNbackground          XtCBackground          Pixel            White
.br
.ti -22
XtNbackgroundPixmap    XtCPixmap              Pixmap           Unspecified
.br
.ti -22
XtNborderWidth         XtCBorderWidth         int              1
.br
.ti -22
XtNborderColor         XtCBorderColor         Pixel            Black
.br
.ti -22
XtNborderPixmap        XtCPixmap              Pixmap           Unspecified
.br
.ti -22
XtNsensitive           XtCSensitive           Boolean          TRUE
.br
.ti -22
XtNmappedWhenManaged   XtCMappedWhenManaged   Boolean          TRUE
.br
.ti -22
XtNdestroyCallback     XtCCallback            Pointer          NULL
.br
.ti -22
XtNtranslations        XtCTranslations        XtTranslations   NULL
.br
.IP "" 11
Manager Resource Set \-\- XWMANAGER(3X)
.ti -16
Name                    Class                   Type        Default
.br
.ti -16
______________________________________________________________________
.br
.ti -16
XtNforeground           XtCForeground           Pixel       Black
.br
.ti -16
XtNbackgroundTile       XtCBackgroundTile       int         background
.br
.ti -16
XtNhighlightThickness   XtCHighlightThickness   int         0
.br
.ti -16
XtNtraversalOn           XtCTraversalOn          Boolean     FALSE
.br
.IP "" 9
MenuPane Resource Set \-\- XWMENUPANE(3X)
.ti -14
Name                  Class              Type            Default
.br
.ti -14
____________________________________________________________________
.br
.ti -14
XtNtitleShowing       XtCTitleShowing    Boolean         FALSE
.br
.ti -14
XtNmgrTitleOverride   XtCTitleOverride   Boolean         FALSE
.br
.ti -14
XtNtitleType          XtCTitleType       int             XwSTRING
.br
.ti -14
XtNtitleString        XtCTitleString     String          widget name
.br
.ti -14
XtNtitleImage         XtCTitleImage      XImage *        NULL
.br
.ti -14
XtNfont               XtCFont            XFontStruct *   "fixed"
.br
.ti -14
XtNattachTo           XtCAttachTo        String          NULL
.br
.ti -14
XtNmnemonic           XtCMnemonic        String          NULL
.br
.ti -14
XtNselect             XtCCallback        Pointer         NULL
.br
.SH TRANSLATIONS
The input to the Cascade menupane widget is driven by the
mouse buttons.  The default translations set by this widget
are as follows:
.IP "" 5
<Btn1Down>:        select()
.br
<LeaveWindow>:     leave()
.br
<visible>:         visible()
.br
<unmap>:           unmap()
.SH ACTIONS
.TP 5
select:
.br
Informs the menu manager, if present, that a select
occurred, and then invokes the select callbacks, unless
instructed not to by the menu manager.  If no menu
manager is present, then the select callbacks will be
invoked.
.TP 5
leave:
.br
This routine overrides the leave action routine
provided by the XwManager meta class.
.TP 5
visible:
.br
This action overrides the visible action routine
provided by the XwManager meta class.
.TP 5
unmap:
.br
This action overrides the unmap action provided by the
XwManager meta class.
.SH "KEYBOARD TRAVERSAL"
If the XtNtraversalOn resource is set to TRUE at create time
or during a call to XtSetValues, the XwManager superclass
will automatically augment the manager widget's translations
to support keyboard traversal.  Refer to the XwManager man
page for a complete description of these translations.
.SH ORIGIN
Hewlett-Packard Company.
.SH "SEE ALSO"
CORE(3X), CONSTRAINT(3X), XWMANAGER(3X), XWMENUPANE(3X),
Programming With The HP X Widgets,
.br
Programming With Xt Intrinsics,
.br
Programming With Xlib.
