.TH XWTOGGLE 3X
.SH NAME
XwtoggleWidgetClass \- the X Widgets toggle button widget
.SH SYNOPSIS
#include <X11/StringDefs.h>
.br
#include <X11/Intrinsic.h>
.br
#include <Xw/Xw.h>
.br
#include <Xw/Toggle.h>
.SH CLASSES
The toggle widget is built from the Core, XwPrimitive and
XwButton classes.
.PP
The widget class to use when creating a toggle is
XwtoggleWidgetClass.  The class name is Toggle.
.SH DESCRIPTION
The toggle widget implements a button which consists of a
graphic and a label.  The label can be positioned either to
the right (the default) or the left of the graphic.  The
size of the graphic is based on the height of the font used
for the label.  The space between the graphic and the label
is equal to 1/3 the font height. The default graphic is a
square box and this may be changed to a diamond shape.  It
is intended that application writers can put a group of
square buttons into a Row Column manager with its mode set
to the default n_of_many to get the checkbox, or N of Many,
selection semantic and then put a group of diamond buttons
into a Row Column manager with its mode set to one_of_many
to get the radiobutton, or One of Many, selection semantic.
.PP
The default semantic for this button is that button 1 down
will toggle the state of the toggle. When in a selected
state, the interior of the graphic will be filled with the
foreground color; when not selected the interior of the
graphic will be filled with the background color; when
insensitive, the label will be drawn with the patterned tile
(the default is a 75/25 mix of the foreground and background
colors).
.PP
Callbacks can be attached to the widget to report selection
(XtNselect) and unselection (XtNrelease).  This widget can
be set to respond to Enter and Leave window events by
highlighting and unhighlighting the button.  This widget is
also capable of handling  keyboard traversal.  See the
translations below for the default traversal keycodes.
.SH "NEW RESOURCES"
The toggle widget class defines a set of resource types that
can be used by the programmer to specify data for widgets of
.PP
this class. Recall that the string to be used when setting
any of these resources in an application defaults file (like
\&.Xdefaults) can be obtained by stripping the preface "XtN"
off of the resource name.  For instance, XtNfont becomes
font.
.IP "" 17
Toggle Resource Set
Name             Class           Type      Default
__________________________________________________
XtNsquare        XtCSquare       Boolean   True
XtNselectColor   XtCForeground   Pixel     Black
.TP 5
XtNsquare
.br
If True, forces the button to draw a square box,
otherwise it will draw a diamond shape box.  One
possible usage for this resource is to make the
convention that row column managers containing diamond
shaped toggles have their XtNmode resource set to
one_of_many which will only allow one of the buttons to
be set at any one time, while row column managers
containing square buttons use the default mode setting
of n_of_many which allows any or all of the buttons to
be set.
.TP 5
XtNselectColor
.br
Allows the application to specify what color should be
used to fill in the center of the square (or the
diamond) when it is set.
.SH "INHERITED RESOURCES"
The following resources are inherited from the named
superclasses: The defaults used for the toggle when being
created are as follows:
.IP "" 17
Core Resource Set \-\- CORE(3X)
.ti -22
Name                   Class                  Type             Default
.br
.ti -22
__________________________________________________________________________
.br
.ti -22
XtNancestorSensitive   XtCSenstitive          Boolean          TRUE
.br
.ti -22
XtNx                   XtCPosition            int              0
.br
.ti -22
XtNy                   XtCPosition            int              0
.br
.ti -22
XtNwidth               XtCWidth               int              0
.br
.ti -22
XtNheight              XtCHeight              int              0
.br
.ti -22
XtNdepth               XtCDepth               int              0
.br
.ti -22
XtNbackground          XtCBackground          Pixel            White
.br
.ti -22
XtNbackgroundPixmap    XtCPixmap              Pixmap           Unspecified
.br
.ti -22
XtNborderWidth         XtCBorderWidth         int              1
.br
.ti -22
XtNborderColor         XtCBorderColor         Pixel            Black
.br
.ti -22
XtNborderPixmap        XtCPixmap              Pixmap           Unspecified
.br
.ti -22
XtNsensitive           XtCSensitive           Boolean          TRUE
.br
.ti -22
XtNmappedWhenManaged   XtCMappedWhenManaged   Boolean          TRUE
.br
.ti -22
XtNdestroyCallback     XtCCallback            Pointer          NULL
.br
.ti -22
XtNtranslations        XtCTranslations        XtTranslations   NULL
.br
.IP "" 10
Primitive Resource Set \-\- XWPRIMITIVE(3X)
.ti -15
Name                    Class                   Type      Default
.br
.ti -15
________________________________________________________________________
.br
.ti -15
XtNforeground           XtCForeground           Pixel     Black
.br
.ti -15
XtNbackgroundTile       XtCBackgroundTile       int       background
.br
.ti -15
XtNtraversalType        XtCTraversalType        int       highlight_off
.br
.ti -15
XtNhighlightStyle       XtCHighlightStyle       int       pattern_border
.br
.ti -15
XtNhighlightColor       XtCForeground           Pixel     Black
.br
.ti -15
XtNhighlightTile        XtCHighlightTile        int       50_foreground
.br
.ti -15
XtNhighlightThickness   XtCHighlightThickness   int       0
.br
.ti -15
XtNrecomputeSize        XtCRecomputeSize        Boolean   TRUE
.br
.ti -15
XtNselect               XtCCallback             Pointer   NULL
.br
.ti -15
XtNrelease              XtCCallback             Pointer   NULL
.br
.IP "" 11
Button Resource Set \-\- XWBUTTON(3X)
.ti -16
Name               Class              Type            Default
.br
.ti -16
___________________________________________________________________
.br
.ti -16
XtNfont            XtCFont            XFontStruct *   Fixed
.br
.ti -16
XtNlabel           XtCLabel           caddr_t         NULL
.br
.ti -16
XtNlabelLocation   XtCLabelLocation   int             right
.br
.ti -16
XtNvSpace          XtCVSpace          int             2
.br
.ti -16
XtNhSpace          XtCHSpace          int             2
.br
.ti -16
XtNset             XtCSet             Boolean         False
.br
.ti -16
XtNsensitiveTile   XtCSensitiveTile   int             75_foreground
.br
.SH "KEYBOARD TRAVERSAL"
If the XtNtraversalType resource is set to
highlight_traversal (XwHIGHLIGHT_TRAVERSAL in an argument
list) at either create time or during a call to XtSetValues,
the XwPrimitive superclass will automatically augment the
primitive widget's translations to support keyboard
traversal.  Refer to the XwPrimitive man page for a complete
description of these translations.  Refer to the
TRANSLATIONS section in this man page for a description of
the translations local to the toggle widget.
.SH TRANSLATIONS
The input to the toggle is driven by the mouse buttons.  The
default translation set defining this button is listed
below.  Note that for the specific key symbols used in
traversal, the HP Key Cap which corresponds to this key
symbol appears to the right of the definition.
.IP "" 6
<Btn1Down>:      toggle()
.br
<EnterWindow>:   enter()
.br
<LeaveWindow>:   leave()
.br
<Key>Select:     toggle()   HP "Select" key
.SH ACTIONS
Note that this widget contains some actions which are not
bound to any events by the default translations.  The
purpose of these additional actions are to allow advanced
users to alter the button semantics to their liking.
.TP 5
toggle:
.br
Toggle the set state of the button (make it TRUE if it
was FALSE, FALSE if it was TRUE).  Redraw only the
toggle part (not the label) of the button. If the
current state of the button is set (TRUE) issue the
XtNselect callbacks, if not set (FALSE) issue the
XtNrelease callbacks.  No additional data beyond the
.IP "" 5
widget id and the specified closure is sent with these
callbacks.
.TP 5
enter:
.br
If the XtNtraversalType resource has been set to
XwHIGHLIGHT_ENTER then the button will be highlighted.
Otherwise no action is taken.
.TP 5
leave:
.br
If the XtNtraversalType resouces has been set to
XwHIGHLIGHT_ENTER then the button will be
unhighlighted.  Otherwise no action is taken.
.SH ORIGIN
Hewlett-Packard Company.
.SH "SEE ALSO"
CORE(3X), XWPRIMITIVE(3X), XWBUTTON(3X),
.br
Programming With The HP X Widgets,
.br
Programming With Xt Intrinsics,
.br
Programming With Xlib.
